@@ -45,7 +45,7 @@ class DiscoveryConnector(MinosSetup):
     @classmethod
     def _from_config(cls, *args, config: MinosConfig, **kwargs) -> DiscoveryConnector:
         client = MinosDiscoveryClient(host=config.discovery.host, port=config.discovery.port)
-        port = config.rest.broker.port
+        port = config.rest.port
         name = config.service.name
         host = get_host_ip()
         return cls(client=client, name=name, host=host, port=port, *args, **kwargs)
